<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Admin;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;

use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;

use App\Managers\User\UserManager;
use App\Managers\Email\EmailManager;
use App\Validators\Admin\AdminEmailValidator;

class AdminEmailController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->userManager = new UserManager();
        $this->emailManager = new EmailManager();
        $this->emailValidator = new AdminEmailValidator();
    }
    
    public function add(Request $request)
    {
        if($request->all() && $request->exists('data'))
        {
            $data = $request->get('data');
            
            $validation = $this->emailValidator->add($data);
            if($validation)
            {
                return redirect()->back()->withErrors($validation['errors']);
                exit;
            }
            $email = $this->emailManager->add($data);
            if(!$email)
            {
                return redirect()->back()->withErrors(['Something Went Wrong']);
                exit;
            }

            $emailGroup = $data['email_groups'];
            
            $emails = $data['emails'];
            $emailsArray = explode(',', $emails);
            $allEmails = array();

            if($emailGroup == 'All Users')
            {
                $allEmailsCollection = $this->userManager->get();
                
                if(!empty($allEmailsCollection))
                foreach($allEmailsCollection AS $email)
                {
                    if($email->email != '')
                    {
                        $allEmails[] = $email->email;
                    }
                }
            }

            if($emailGroup == 'Users with active votes')
            {
                $allEmailsCollection = $this->userManager->select('users.email')->join('paypal', 'paypal.user_id', '=', 'users.UUID')->where('paypal.expiry_date', '>=', date("Y-m-d"))->groupBy('users.UUID')->get();
                
                if(!empty($allEmailsCollection))
                foreach($allEmailsCollection AS $email)
                {
                    if($email->email != '')
                    {
                        $allEmails[] = $email->email;
                    }
                }
            }

            if($emailGroup == 'Confirmed accounts with notification option yes')
            {
                $allEmailsCollection = $this->userManager->select('users.email')->where('notification', 1)->where('confirmation_code', 1)->get();
                
                if(!empty($allEmailsCollection))
                foreach($allEmailsCollection AS $email)
                {
                    if($email->email != '')
                    {
                        $allEmails[] = $email->email;
                    }
                }
            }

            if($emailGroup == 'Confirmed accounts with notification option yes(Excluding users with active votes)')
            {
                $allEmailsCollection = $this->userManager->select('users.email')->where('notification', 1)->where('confirmation_code', 1)->get();
                
                 $allUsersActiveVotes = $this->userManager->select('users.email')->join('paypal', 'paypal.user_id', '=', 'users.UUID')->where('paypal.expiry_date', '>=', date("Y-m-d"))->groupBy('users.UUID')->get();

                 $usersEmailArray = array();
                 foreach($allUsersActiveVotes AS $allUsersActiveVote)
                 {
                    $usersEmailArray = $allUsersActiveVote->email;
                 }

                if(!empty($allEmailsCollection))
                foreach($allEmailsCollection AS $email)
                {
                    if($email->email != '' && !in_array($email->email, $usersEmailArray))
                    {
                        $allEmails[] = $email->email;
                    }
                }
            }
            
            foreach($emailsArray AS $email)
            {
                if($email != 'All Emails With Active Votes')
                {
                    if($email != '')
                    {
                        $allEmails[] = $email;
                    }
                }
                
            }
            
            $resultData['allEmails'] = $allEmails;
            $resultData['data'] = $data;
           // $emails = ['myoneemail@esomething.com', 'myother@esomething.com','myother2@esomething.com'];
           
            Mail::send('emails.send', ['body' => $data['body'], 'url' => url('/')], function($message) use ($resultData)
            {    
                $message->to($resultData['allEmails'])->cc($resultData['data']['cc'])->bcc($resultData['data']['bcc'])->subject($resultData['data']['subject']);    
            });
            return redirect()->back()->withErrors(['Email Sent Successfully']);
            exit;
        }
        return view('/admin/email/add');
    }
    
}