<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Managers\Schedule;
use App\Managers\Schedule\ScheduleModel;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use App\Managers\SchedulePlayers\SchedulePlayersManager;
use App\Managers\PlayerRatings\PlayerRatingsManager;
use App\Managers\PlayerRatingSubstitute\PlayerRatingSubstituteManager;
use App\Managers\SchedulePreMatchFormation\SchedulePreMatchFormationManager;
use App\Managers\TacticContainer\TacticContainerManager;
use App\Managers\PlayerRatingsVotes\PlayerRatingsVotesManager;
use App\Managers\Tactics\TacticsManager;
use Illuminate\Support\Facades\DB;
use App\Http\Helper\Helper;

class ScheduleManager extends ScheduleModel
{
    public function __construct()
    {
         $this->helper = new Helper();
    }

    public function add($data)
    {
        
        $data['user_id'] = Session::get('admin');
        return $this->insertGetId($data);
    }
    
    public function updateData($data, $UUID)
    {
        return $this->where('UUID', $UUID)->update($data);
    }
    
    public function updateSchedulePlayerData($data, $columns, $UUID)
    {
        DB::beginTransaction();
        try 
        {
            $this->schedulePlayer = new SchedulePlayersManager();
            $data['updated_at'] = date("Y-m-d H:i:s");
            $update = $this->where('UUID', $UUID)->update($data);
            if(!$update)
            {
                return 0;
            }
            $scheduledPlayers = $this->schedulePlayer->where('schedule_id', $UUID)->get();
            if(count($scheduledPlayers) > 0)
            {
                $del = $this->schedulePlayer->where('schedule_id', $UUID)->update(array('inactive' => 0));
                if(!$del)
                {
                    return 0;
                }
            }
            
            if(empty($columns))
            {
                return 0;
            }
            foreach($columns AS $key => $column)
            {
                
                if($key == 'undefined')
                {
                    return 0;
                }
                $data = array();
                $data['position_columns_id'] = $key;
                $data['schedule_id'] = $UUID;
                $data['player_id'] = $column['player_id'];
                $data['goal'] = $column['goal'];
                $data['user_id'] = Session::get('admin');
                
                $data['UUID'] = $this->helper->addUUID();
                $data['updated_at'] = $data['updated_at'] = date("Y-m-d H:i:s");
                
                $insert = $this->schedulePlayer->insert($data);
                if(!$insert)
                {
                    return 0;
                }
            }
            
            DB::commit();
            return 1;
        }
        catch(ValidationException $e)
        {
            DB::rollback();
            return 0;
        }
        
    }
    
    
    public function getLatestMatchPreFormation($tacticsDaysLimit)
    {
       
        $todayDate = date('Y-m-d');
        $futuredate = date('Y-m-d', strtotime("+" . $tacticsDaysLimit . " days"));
        $now = date("Y-m-d H:i:s");
        $newTime = date("H:i:s", strtotime("+" . $tacticsDaysLimit . " minutes", strtotime($now)));;
        //echo $newTime = date("H:i:s", $calTime);
        return $this->select('schedule_pre_match_formation.formation_id', 'date_date', 'time_time', 'schedule.UUID')
            ->join('schedule_pre_match_formation', 'schedule.UUID', '=', 'schedule_pre_match_formation.schedule_id')
            ->where(function($query) use ($todayDate, $futuredate)
                {
                    $query->where('date_date', '>', $todayDate)
                    ->where('date_date', '<', $futuredate);
                })
            ->orWhere(function($query) use ($todayDate, $newTime)
                    {
                        $query->where('date_date', $todayDate)
                                ->where('time_time', '>=', $newTime);
                    })
            ->orderBy('date_date', 'ASC')->orderBy('time_time', 'ASC')
            ->first();
    }
    
    public function getLatestMatchPreFormationWithoutLimit()
    {
       
        $todayDate = date('Y-m-d');
        //$futuredate = date('Y-m-d', strtotime("+" . $tacticsDaysLimit . " days"));
        $now = date("Y-m-d H:i:s");
        //$newTime = date("H:i:s", strtotime("+" . $tacticsDaysLimit . " minutes", strtotime($now)));;
        //echo $newTime = date("H:i:s", $calTime);
        return $this->select('schedule_pre_match_formation.formation_id', 'date_date', 'time_time', 'schedule.UUID')
            ->join('schedule_pre_match_formation', 'schedule.UUID', '=', 'schedule_pre_match_formation.schedule_id')
            ->where(function($query) use ($todayDate)
                {
                    $query->where('date_date', '>', $todayDate);
                  //  ->where('date_date', '<', $futuredate);
                })
            ->orWhere(function($query) use ($todayDate)
                    {
                        $query->where('date_date', $todayDate);
                            //    ->where('time_time', '>=', $newTime);
                    })
            ->orderBy('date_date', 'ASC')->orderBy('time_time', 'ASC')
            ->first();
    }
    
     public function getLatestMatchPreFormationWithoutLimit1()
    {
       
        $todayDate = date('Y-m-d');
        //$futuredate = date('Y-m-d', strtotime("+" . $tacticsDaysLimit . " days"));
        $now = date("Y-m-d H:i:s");
        //$newTime = date("H:i:s", strtotime("+" . $tacticsDaysLimit . " minutes", strtotime($now)));;
        //echo $newTime = date("H:i:s", $calTime);
        return $this->select('schedule_pre_match_formation.formation_id', 'date_date', 'time_time', 'schedule.UUID', 'schedule.name')
            ->join('schedule_pre_match_formation', 'schedule.UUID', '=', 'schedule_pre_match_formation.schedule_id')
            ->where(function($query) use ($todayDate)
                {
                    $query->where('date_date', '>', $todayDate);
                  //  ->where('date_date', '<', $futuredate);
                })
            ->orWhere(function($query) use ($todayDate)
                    {
                        $query->where('date_date', $todayDate);
                            //    ->where('time_time', '>=', $newTime);
                    })
            ->orderBy('schedule.date_date', 'ASC')->orderBy('schedule.time_time', 'ASC')
            ->first();
    }
    
    public function getLatestMatchPreFormationWithoutLimit2()
    {
       
        $todayDate = date('Y-m-d');
        //$futuredate = date('Y-m-d', strtotime("+" . $tacticsDaysLimit . " days"));
        $now = date("Y-m-d H:i:s");
        //$newTime = date("H:i:s", strtotime("+" . $tacticsDaysLimit . " minutes", strtotime($now)));;
        //echo $newTime = date("H:i:s", $calTime);
        return $this->select('schedule_pre_match_formation.formation_id', 'date_date', 'time_time', 'schedule.UUID', 'schedule.name')
            ->join('schedule_pre_match_formation', 'schedule.UUID', '=', 'schedule_pre_match_formation.schedule_id')
            ->where(function($query) use ($todayDate)
                {
                    $query->where('date_date', '<', $todayDate);
                  //  ->where('date_date', '<', $futuredate);
                })
            ->orWhere(function($query) use ($todayDate)
                    {
                        $query->where('date_date', $todayDate);
                            //    ->where('time_time', '>=', $newTime);
                    })
            ->orderBy('schedule.date_date', 'DESC')->orderBy('schedule.time_time', 'DESC')
            ->first();
    }
    
    public function getCurrentMatchPreFormation($UUID)
    {
        
        $todayDate = date('Y-m-d');
        $futuredate = date('Y-m-d', strtotime("+30 days"));
        $now = date("Y-m-d H:i:s");
        $newTime = date("H:i:s", strtotime("+30 minutes", strtotime($now)));;
        //echo $newTime = date("H:i:s", $calTime);
        return $this->select('schedule_pre_match_formation.formation_id', 'date_date', 'time_time', 'schedule.UUID')
            ->join('schedule_pre_match_formation', 'schedule.UUID', '=', 'schedule_pre_match_formation.schedule_id')
            ->where('schedule.UUID', $UUID)
            ->orderBy('date_date', 'ASC')->orderBy('time_time', 'ASC')
            ->first();
    }
    
    public function getCurrentMatchCount($scheduleID)
    {
        $schedule = $this->where('UUID', $scheduleID)->first();
        return $this->select(DB::raw("COUNT(*) as match_number"))
                ->where('date_date', '<', $schedule->date_date )
                ->orWhere(function($query) use ($schedule)
                    {
                        $query->where('date_date', $schedule->date_date)
                                ->where('time_time', '<=', $schedule->time_time);
                    })->get();
    }
    
    public function getLatestPlayedMatchFormation($playerEvaluationDaysLimit)
    {
        $todayDate = date('Y-m-d');
        $predate = date('Y-m-d', strtotime("-" . $playerEvaluationDaysLimit . " days"));
        $now = date("Y-m-d H:i:s");
        $nowTime = date("H:i:s");
       // $newTime = date("H:i:s", strtotime("+30 minutes", strtotime($now)));;
       // $newTime = date("H:i:s", $calTime);
        return $this->with('sub1','sub2', 'sub3', 'sub4', 'sub5')->select('formation_id', 'date_date', 'time_time', 'UUID', 'column_count_1', 'new_player_1', 'column_count_2', 'new_player_2', 'column_count_3', 'new_player_3', 'column_count_4', 'new_player_4', 'column_count_5', 'new_player_5')
            
            ->where('date_date', '<', $todayDate)
            ->orWhere(function($query) use ($todayDate, $nowTime)
                    {
                        $query->where('date_date', $todayDate)
                                ->where('time_time', '<=', $nowTime);
                    })
            ->orderBy('date_date', 'DESC')->orderBy('time_time', 'DESC')
            ->first();
    }
    
    public function deleteData($UUID)
    {
        DB::beginTransaction();
        try 
        {
            $this->SchedulePreMatchFormationManager = new SchedulePreMatchFormationManager();
            $this->playerRatings = new PlayerRatingsManager();
            $this->schedulePlayer = new SchedulePlayersManager();
            $this->playerRatingSubstitute = new PlayerRatingSubstituteManager();
            $this->playerRatingsVotesManager = new PlayerRatingsVotesManager();
            $this->tacticContainerManager = new TacticContainerManager();
            $this->tacticsManager = new TacticsManager();
            $playerRatingsSubstitutes = $this->playerRatingSubstitute->where('scheduled_id', $UUID)->get();
            if(!empty($playerRatingsSubstitutes))
            {
                foreach($playerRatingsSubstitutes AS $playerRatingsSubstitute)
                {
                    $playerRatingsSubstituteID = $playerRatingsSubstitute['UUID'];
                     $this->playerRatings->where('player_ratings_substitute_id', $playerRatingsSubstituteID)->delete();
                    
                }
            }

            $this->playerRatingSubstitute->where('scheduled_id', $UUID)->delete();
            $this->schedulePlayer->where('schedule_id', $UUID)->delete();
            $this->SchedulePreMatchFormationManager->where('schedule_id', $UUID)->delete();
            
                
            $tacticContainers = $this->tacticContainerManager->where('schedule_id', $UUID)->get();
            if(!empty($tacticContainers))
            {
                foreach($tacticContainers AS $tacticContainer)
                {
                    $tacticContainerID = $tacticContainer['UUID'];
                    $this->tacticsManager->where('tactic_container_id', $tacticContainerID)->delete();
                    
                }
            }
            $this->tacticContainerManager->where('schedule_id', $UUID)->delete();
            $this->playerRatingsVotesManager->where('schedule_id', $UUID)->delete();
            $res = $this->where('UUID', $UUID)->delete();
            if(!$res)
            {
                DB::rollback();
                return 0;
                exit;
            }
            
            DB::commit();
            return 1;
        }
        catch(ValidationException $e)
        {
            DB::rollback();
            return 0;
            exit;
        }
    }
}